## dbt-snowflake 1.9.2 - March 07, 2025

### Features

- Support MicrobatchConcurrency ([#1260](https://github.com/dbt-labs/dbt-adapters/issues/1260))
- Added support for custom iceberg base_location_root ([#1284](https://github.com/dbt-labs/dbt-adapters/issues/1284))
- Add insert_overwrite 'incremental' strategy. ([#736](https://github.com/dbt-labs/dbt-adapters/issues/736))

### Fixes

- Fix parsing of the VECTOR type ([#1098](https://github.com/dbt-labs/dbt-adapters/issues/1098))
- Use timestamp_tz type in microbatch `delete` DDL ([#1256](https://github.com/dbt-labs/dbt-adapters/issues/1256))
- AUTO should no longer lead to rebuilds of dynamic tables. ([#1267](https://github.com/dbt-labs/dbt-adapters/issues/1267))
- Loosen pin for snowflake-connector-python to pin at 3.x ([#835](https://github.com/dbt-labs/dbt-adapters/issues/835))

### Under the Hood

- Move from setup.py to pyproject.toml and to hatch as a dev tool ([#1250](https://github.com/dbt-labs/dbt-adapters/issues/1250))
- Use new `batch` context variables over `node.config.__dbt_internal` ones ([#1263](https://github.com/dbt-labs/dbt-adapters/issues/1263))
- Update default Python version for python models ([#1203](https://github.com/dbt-labs/dbt-adapters/issues/1203))
- Expand types allowed in columns to allow structured types. ([#310](https://github.com/dbt-labs/dbt-adapters/issues/310))

### Security

- Resolve CVE-2025-24794 ([#859](https://github.com/dbt-labs/dbt-adapters/pull/859))

### Contributors
- [@LProcopi15](https://github.com/LProcopi15) ([#1284](https://github.com/dbt-labs/dbt-adapters/issues/1284))
- [@achawkins](https://github.com/achawkins) ([#1098](https://github.com/dbt-labs/dbt-adapters/issues/1098))
